# Separator parameters

Parameters for an LG M50 separator, from the paper

> Kieran O’Regan, Ferran Brosa Planella, W. Dhammika Widanage, and Emma Kendrick. ["Thermal-electrochemical parameters of a high energy lithium-ion cylindrical battery."](https://www.sciencedirect.com/science/article/pii/S0013468622008593) Electrochimica Acta 425 (2022): 140700

and references therein.
